==> xfxwidgets-1.9.5.tar.gz: lib/XF_MAIN/XAppState.dart <==
// part of xfxbase;

// XFX LEVEL
import 'dart:typed_data';

import 'package:camera/camera.dart';
import 'package:flutter/material.dart';
import 'package:observable/observable.dart' as Observable;
import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:xfxbase/XAppStateBase.dart';

import 'XArea.dart';

class XAppState extends XAppStateBase {
  XAppState() {
    _li_XAree.changes.listen((event) {
      notifyListeners();
    });
  }

  Future<ConnectivityResult> get connectivityResult async {
    return Connectivity().checkConnectivity();
  }

  late List<CameraDescription> cameras = <CameraDescription>[];
  bool isolate_Active = true;
  bool isOwner = false;
  bool isManager = false;
  bool homeLayoutComplex = false;

  String PgName_Login = 'Login';
  XArea _area_Active = XArea("", 0, Container());
  XArea get area_Active => _area_Active;
  set area_Active(XArea? newValue) {
    _area_Active = newValue!;
    notifyListeners();
  }

  GlobalKey<ScaffoldState> scaffoldKey_MainMenu = GlobalKey<ScaffoldState>();

  List<XArea> liXMenuItem = List<XArea>.empty(growable: true);
  List<XAction> liXActions = List<XAction>.empty(growable: true);
  Observable.ObservableList<XArea> _li_XAree = Observable.ObservableList<XArea>();
  Observable.ObservableList<XArea> get li_XAree => _li_XAree;
}

class XAction {
  int? idx;
  String? key;
  String? toolTip;
  dynamic Function(dynamic, void Function(void Function()) parentSetState)? cmd;
  Color? background_Color;
  IconData? icon;
  Color? icon_Color;
  Uint8List? icon_Image;
  String? label;
  Color? label_Color;
  bool fastAction;

  ///Se Pieno l'action farà vedere questo child
  Widget? child;

  ///true = LEFT e false = RIGHT
  bool leftORright;

  XAction(
    this.key,
    this.idx,
    this.label, {
    this.cmd,
    this.toolTip,
    this.background_Color,
    this.icon,
    this.leftORright = true,
    this.icon_Color,
    this.icon_Image,
    this.label_Color,
    this.child,
    this.fastAction = false,
  });
}

==> xfxwidgets-1.9.25.tar.gz: lib/XF_MAIN/XAppState.dart <==
// part of xfxbase;

// XFX LEVEL
import 'dart:typed_data';

import 'package:camera/camera.dart';
import 'package:flutter/material.dart';
import 'package:observable/observable.dart' as Observable;
import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:xfxbase/XAppStateBase.dart';
import 'package:xfxbase/XFDataItem.dart';

import 'XArea.dart';

class XAppState extends XAppStateBase {
  XAppState() {
    _li_XAree.changes.listen((event) {
      notifyListeners();
    });
  }

  Future<ConnectivityResult> get connectivityResult async {
    return Connectivity().checkConnectivity();
  }

  late List<CameraDescription> cameras = <CameraDescription>[];
  bool isolate_Active = true;
  bool isOwner = false;
  bool isManager = false;
  bool homeLayoutComplex = false;

  String PgName_Login = 'Login';
  XArea _area_Active = XArea("", 0, Container());
  XArea get area_Active => _area_Active;
  set area_Active(XArea? newValue) {
    _area_Active = newValue!;
    notifyListeners();
  }

  GlobalKey<ScaffoldState> scaffoldKey_MainMenu = GlobalKey<ScaffoldState>();

  List<XArea> liXMenuItem = List<XArea>.empty(growable: true);
  List<XAction> liXActions = List<XAction>.empty(growable: true);
  Observable.ObservableList<XArea> _li_XAree = Observable.ObservableList<XArea>();
  Observable.ObservableList<XArea> get li_XAree => _li_XAree;
}

class XAction {
  int? idx;
  String? key;
  String? toolTip;
  dynamic Function(XFDataItem?, void Function(void Function()) parentSetState, BuildContext context)? cmd;
  Color? background_Color;
  IconData? icon;
  Color? icon_Color;
  Uint8List? icon_Image;
  String? label;
  Color? label_Color;
  bool fastAction;

  ///Se Pieno l'action farà vedere questo child
  Widget? child;

  ///true = LEFT e false = RIGHT
  bool leftORright;

  XAction(
    this.key,
    this.idx,
    this.label, {
    this.cmd,
    this.toolTip,
    this.background_Color,
    this.icon,
    this.leftORright = true,
    this.icon_Color,
    this.icon_Image,
    this.label_Color,
    this.child,
    this.fastAction = false,
  });
}
